#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HsOpenSSL-x509-system
version:              0.1.0.4
visibility:           public
id:                   HsOpenSSL-x509-system-0.1.0.4-IOZKNs9K739KakbdStdEDd
key:                  HsOpenSSL-x509-system-0.1.0.4-IOZKNs9K739KakbdStdEDd
license:              BSD-3-Clause
maintainer:           Marios Titas <rednebΑΤgmxDΟΤcom>
author:               Marios Titas <rednebΑΤgmxDΟΤcom>
homepage:             https://github.com/redneb/HsOpenSSL-x509-system
synopsis:             Use the system'\''s native CA certificate store with HsOpenSSL
description:
    A cross-platform library that tries to find a (reasonable) CA certificate
    bundle that can be used with @HsOpenSSL@ to verify the certificates of
    remote peers.

    This package is for @HsOpenSSL@ what @x509-system@ is for the @tls@ package.
    Additionally, it borrows some ideas from @x509-system@.

category:             System, Filesystem
abi:                  bdd16f9240365eb51d4977e82b912f88
exposed:              True
exposed-modules:      OpenSSL.X509.SystemStore
hidden-modules:       OpenSSL.X509.SystemStore.Unix
import-dirs:          /usr/lib/ghc-9.6.6/site-local/HsOpenSSL-x509-system-0.1.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/HsOpenSSL-x509-system-0.1.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/HsOpenSSL-x509-system-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsopenssl-x509-system
hs-libraries:         HSHsOpenSSL-x509-system-0.1.0.4-IOZKNs9K739KakbdStdEDd
depends:
    HsOpenSSL-0.11.7.9-nkYimBP6b58hlFFR12MyK base-4.18.2.1
    bytestring-0.11.5.3 unix-2.8.4.0

haddock-interfaces:
    /usr/share/doc/haskell-hsopenssl-x509-system/html/HsOpenSSL-x509-system.haddock

haddock-html:         /usr/share/doc/haskell-hsopenssl-x509-system/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

